@@ -3,7 +3,7 @@ package SVG::TT::Graph::Pie;
 use strict;
 use Carp;
 use vars qw($VERSION);
-$VERSION = '0.06';
+$VERSION = '0.09';
 
 use SVG::TT::Graph;
 use base qw(SVG::TT::Graph);
@@ -402,73 +402,73 @@ __DATA__
 
 
 /* key - MUST match fill styles */
-.key1,.fill1{
+.key1,.dataPoint1{
 	fill: #ff0000;
 	fill-opacity: 0.5;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key2,.fill2{
+.key2,.dataPoint2{
 	fill: #0000ff;
 	fill-opacity: 0.5;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key3,.fill3{
+.key3,.dataPoint3{
 	fill-opacity: 0.5;
 	fill: #00ff00;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key4,.fill4{
+.key4,.dataPoint4{
 	fill-opacity: 0.5;
 	fill: #ffcc00;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key5,.fill5{
+.key5,.dataPoint5{
 	fill-opacity: 0.5;
 	fill: #00ccff;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key6,.fill6{
+.key6,.dataPoint6{
 	fill-opacity: 0.5;
 	fill: #ff00ff;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key7,.fill7{
+.key7,.dataPoint7{
 	fill-opacity: 0.5;
 	fill: #00ff99;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key8,.fill8{
+.key8,.dataPoint8{
 	fill-opacity: 0.5;
 	fill: #ffff00;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key9,.fill9{
+.key9,.dataPoint9{
 	fill-opacity: 0.5;
 	fill: #cc6666;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key10,.fill10{
+.key10,.dataPoint10{
 	fill-opacity: 0.5;
 	fill: #663399;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key11,.fill11{
+.key11,.dataPoint11{
 	fill-opacity: 0.5;
 	fill: #339900;
 	stroke: none;
 	stroke-width: 1px;	
 }
-.key12,.fill12{
+.key12,.dataPoint12{
 	fill-opacity: 0.5;
 	fill: #9966FF;
 	stroke: none;
@@ -662,24 +662,24 @@ __DATA__
 		[% xe = re * cos(radians_half) FILTER format('%02.10f') %]
 		[% ye = re * sin(radians_half) FILTER format('%02.10f') %]
 
-        <path d="M[% px_start + xe %] [% pmin_scale_value + ye %] A[% r %] [% r %], 0, 
-        [% IF percent >= 50 %]1[% ELSE %]0[% END %], 1, [% x + px_end + xe %] [% y + py_end + ye %] L[% x + xe %] [% y + ye %], Z" class="dataPoint[% count %]"/>
+        <path d="M[% px_start + xe %] [% pmin_scale_value + ye %] A[% r %] [% r %] 0 
+        [% IF percent >= 50 %]1[% ELSE %]0[% END %] 1 [% x + px_end + xe %] [% y + py_end + ye %] L[% x + xe %] [% y + ye %] Z" class="dataPoint[% count %]"/>
 	
 	[% ELSIF !config.expanded && config.expand_greatest %]
 		[% IF data.0.data.$field == max_value %]
 		    [% re = r / e %]
 		    [% xe = re * cos(radians_half) FILTER format('%02.10f') %]
 		    [% ye = re * sin(radians_half) FILTER format('%02.10f') %]
-		    <path d="M[% px_start + xe %] [% pmin_scale_value + ye %] A[% r %] [% r %], 0, 
-            [% IF percent >= 50 %]1[% ELSE %]0[% END %], 1, [% x + px_end + xe %] [% y + py_end + ye %] L[% x + xe %] [% y + ye %], Z" class="dataPoint[% count %]"/>
+		    <path d="M[% px_start + xe %] [% pmin_scale_value + ye %] A[% r %] [% r %] 0 
+            [% IF percent >= 50 %]1[% ELSE %]0[% END %] 1 [% x + px_end + xe %] [% y + py_end + ye %] L[% x + xe %] [% y + ye %] Z" class="dataPoint[% count %]"/>
 		[% ELSE %]
-			<path d="M[% px_start %] [% pmin_scale_value %] A[% r %] [% r %], 0, 
-            [% IF percent >= 50 %]1[% ELSE %]0[% END %], 1, [% x + px_end %] [% y + py_end %] L[% x %] [% y %], Z" class="dataPoint[% count %]"/>    
+			<path d="M[% px_start %] [% pmin_scale_value %] A[% r %] [% r %] 0 
+            [% IF percent >= 50 %]1[% ELSE %]0[% END %] 1 [% x + px_end %] [% y + py_end %] L[% x %] [% y %] Z" class="dataPoint[% count %]"/>    
 		[% END %]
 	
 	[% ELSE %]
-		<path d="M[% px_start %] [% pmin_scale_value %] A[% r %] [% r %], 0, 
-        [% IF percent >= 50 %]1[% ELSE %]0[% END %], 1, [% x + px_end %] [% y + py_end %] L[% x %] [% y %], Z" class="dataPoint[% count %]"/>    
+		<path d="M[% px_start %] [% pmin_scale_value %] A[% r %] [% r %] 0 
+        [% IF percent >= 50 %]1[% ELSE %]0[% END %] 1 [% x + px_end %] [% y + py_end %] L[% x %] [% y %] Z" class="dataPoint[% count %]"/>    
 	[% END %]
 	
 	
@@ -779,4 +779,4 @@ __DATA__
 		<text x="[% x %]" y="[% y_subtitle %]" class="subTitle">[% config.graph_subtitle %]</text>
 	[% END %]
 
-</svg>
\ No newline at end of file
+</svg>
