@@ -8,7 +8,7 @@ use DateTime;
 use POSIX;
 
 use vars qw($VERSION);
-$VERSION = '0.07';
+$VERSION = '0.09';
 
 use SVG::TT::Graph;
 use base qw(SVG::TT::Graph);
@@ -1035,7 +1035,7 @@ __DATA__
             [% WHILE ((x_value > calc.min_timescale_value) && ((x_value < calc.max_timescale_value))) %]
                 [% xpos = (dw * (x_value - calc.min_timescale_value)) + x %]
                 [% IF (config.stagger_x_labels && ((count % 2) == 0)) %]
-                    <path d="M[% xpos %] [% base_line %], v[% stagger %]" class="staggerGuideLine" />
+                    <path d="M[% xpos %] [% base_line %] v[% stagger %]" class="staggerGuideLine" />
                     <text x="[% xpos %]" y="[% base_line + 15 + stagger %]" [% IF config.rotate_x_labels %] transform="rotate(90 [% xpos  - half_char_height %] [% base_line + 15 + stagger %]) translate(-10,0)" style="text-anchor: start" [% END %] class="xAxisLabels">[% date.format(x_value,config.x_label_format) %]</text>        
                 [% ELSE %]
                     <text x="[% xpos %]" y="[% base_line + 15 %]" [% IF config.rotate_x_labels %] transform="rotate(90 [% xpos  - half_char_height %] [% base_line + 15 %]) translate(-10,0)" style="text-anchor: start" [% END %] class="xAxisLabels">[% date.format(x_value,config.x_label_format) %]</text>        
